16.1. cdist-type__acl(7) — cdist 4.11.0 documentation

# 16.1. cdist-type__acl(7)

## 16.1.1. NAME

cdist-type__acl - Set ACL entries

## 16.1.2. DESCRIPTION

ACL must be defined as 3-symbol combination, using `r`, `w`, `x` and `-`.

Fully supported on Linux (tested on Debian and CentOS).

Partial support for FreeBSD, OSX and Solaris.

OpenBSD and NetBSD support is not possible.

See `setfacl` and `acl` manpages for more details.

## 16.1.3. OPTIONAL MULTIPLE PARAMETERS

user
  Add user ACL entry.
group
  Add group ACL entry.

## 16.1.4. OPTIONAL PARAMETERS

mask
  Add mask ACL entry.
other
  Add other ACL entry.

## 16.1.5. BOOLEAN PARAMETERS

recursive
  Make `setfacl` recursive (Linux only), but not `getfacl` in explorer.
default
  Add default ACL entries (FreeBSD not supported).
remove
  Remove undefined ACL entries (Solaris not supported). ACL entries for `mask` and `other` can't be removed.

## 16.1.6. EXAMPLES

    __acl /srv/project \
        --recursive \
        --default \
        --remove \
        --user alice:rwx \
        --user bob:r-x \
        --group project-group:rwx \
        --group some-other-group:r-x \
        --mask r-x \
        --other r-x

## 16.1.7. AUTHORS

Ander Punnar <ander-at-kvlt-dot-ee>

## 16.1.8. COPYING

Copyright (C) 2018 Ander Punnar. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.